@@ -1,11 +1,12 @@
 
 #include <memory>
 #include <sstream>
+#include <functional>
 
 #include <curl/curl.h>
 #include <jwt-cpp/base.h>
 #include <jwt-cpp/jwt.h>
-#include <jwt-cpp/picojson.h>
+#include <picojson/picojson.h>
 #include <openssl/bn.h>
 #include <openssl/ec.h>
 
@@ -45,7 +46,10 @@ public:
         }
 
         if (m_maxbytes > 0) {
-            m_data.reserve(std::min(m_maxbytes, 8*1024));
+            size_t new_size = std::min(m_maxbytes, 8*1024);
+            if (m_data.size() < new_size) {
+                m_data.resize(new_size);
+            }
         }
 
         curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
@@ -81,7 +85,9 @@ private:
         if (myself->m_maxbytes > 0 && (new_length > static_cast<size_t>(myself->m_maxbytes))) {
             return 0;
         }
-        myself->m_data.reserve(new_length);
+        if (myself->m_data.size() < new_length) {
+            myself->m_data.resize(new_length);
+        }
         memcpy(&(myself->m_data[myself->m_len]), buffer, new_data);
         myself->m_len = new_length;
         return new_data;
@@ -100,7 +106,7 @@ parse_url(const std::string &url, std::string &schema, std::string &netloc,
     schema.reserve(distance(url.begin(), prot_iter));
     std::transform(url.begin(), prot_iter,
                   std::back_inserter(schema),
-                  std::ptr_fun<int,int>(tolower));
+                  std::function<int(int)>(tolower));
     if (prot_iter == url.end() )
     {
         throw InvalidIssuerException("Issuer URL missing hostname.");
@@ -110,7 +116,7 @@ parse_url(const std::string &url, std::string &schema, std::string &netloc,
     netloc.reserve(std::distance(prot_iter, path_iter));
     std::transform(prot_iter, path_iter,
                    std::back_inserter(netloc),
-                   std::ptr_fun<int,int>(tolower));
+                   std::function<int(int)>(tolower));
     std::string::const_iterator query_iter = std::find(path_iter, url.end(), '?');
     path.assign(path_iter, query_iter);
 }
@@ -580,16 +586,20 @@ scitokens::Enforcer::scope_validator(const jwt::claim &claim, void *myself) {
 
         // If we are in compatibility mode and this is a WLCG token, then translate the authorization
         // names to utilize the SciToken-style names.
+        std::string alt_authz;
         if (me->m_validate_profile == SciToken::Profile::COMPAT &&
             me->m_validator.get_profile() == SciToken::Profile::WLCG_1_0) {
             if (authz == "storage.read") {
                 authz = "read";
-            } else if (authz == "storage.write") {
+            } else if (authz == "storage.create") {
                 authz = "write";
+                alt_authz = "create";
             } else if (authz == "storage.modify") {
                 authz = "write";
+                alt_authz = "modify";
             } else if (authz == "compute.read") {
-                authz = "condor:/READ";
+                authz = "condor";
+                path = "/READ";
             } else if (authz == "compute.modify") {
                 compat_modify = true;
             } else if (authz == "compute.create") {
@@ -601,7 +611,8 @@ scitokens::Enforcer::scope_validator(const jwt::claim &claim, void *myself) {
 
         if (me->m_test_authz.empty()) {
             me->m_gen_acls.emplace_back(authz, path);
-        } else if ((me->m_test_authz == authz) &&
+            if (!alt_authz.empty()) me->m_gen_acls.emplace_back(alt_authz, path);
+        } else if (((me->m_test_authz == authz) || (!alt_authz.empty() &&  (me->m_test_authz == alt_authz))) &&
                    (requested_path.substr(0, path.size()) == path)) {
             return true;
         }
